==> mjml-table-4.4.1.jar: META-INF/resources/webjars/mjml-table/4.4.1/README.md <==
## mjml-table

This tag allows you to display table and filled it with data. It only accepts plain HTML.

```xml
<mjml>
  <mj-body>
    <mj-section>
      <mj-column>
        <mj-table>
          <tr style="border-bottom:1px solid #ecedee;text-align:left;padding:15px 0;">
            <th style="padding: 0 15px 0 0;">Year</th>
            <th style="padding: 0 15px;">Language</th>
            <th style="padding: 0 0 0 15px;">Inspired from</th>
          </tr>
          <tr>
            <td style="padding: 0 15px 0 0;">1995</td>
            <td style="padding: 0 15px;">PHP</td>
            <td style="padding: 0 0 0 15px;">C, Shell Unix</td>
          </tr>
          <tr>
            <td style="padding: 0 15px 0 0;">1995</td>
            <td style="padding: 0 15px;">JavaScript</td>
            <td style="padding: 0 0 0 15px;">Scheme, Self</td>
          </tr>
        </mj-table>
      </mj-column>
    </mj-section>
  </mj-body>
</mjml>
```

<p align="center">
  <a href="https://mjml.io/try-it-live/components/table">
    <img width="100px" src="https://mjml.io/assets/img/svg/TRYITLIVE.svg" alt="try it live" />
  </a>
</p>

attribute                   | unit                        | description                    | default value
----------------------------|-----------------------------|------------------------------- |--------------
align                       | left/right/center           | self horizontal alignment      | left
border                      | border                      | table external border          | none
cellpadding                 | pixels                      | space between cells            | n/a
cellspacing                 | pixels                      | space between cell and border  | n/a
color                       | color                       | text header & footer color     | #000000
container-background-color  | color                       | inner element background color | n/a
css-class                   | string                      | class name, added to the root HTML element created | n/a
font-family                 | string                      | font name                      | Ubuntu, Helvetica, Arial, sans-serif
font-size                   | px                          | font size                      | 13px
font-style                  | string                      | font style                     | n/a
line-height                 | percent/px                  | space between lines            | 22px
padding                     | percent/px                  | supports up to 4 parameters    | 10px 25px
padding-bottom              | percent/px                  | bottom offset                  | n/a
padding-left                | percent/px                  | left offset                    | n/a
padding-right               | percent/px                  | right offset                   | n/a
padding-top                 | percent/px                  | top offset                     | n/a
table-layout                | auto/fixed/initial/inherit  | sets the table layout.         | auto
width                       | percent/px                  | table width                    | 100%

==> mjml-table-4.15.3.jar: META-INF/resources/webjars/mjml-table/4.15.3/README.md <==
## mj-table

This tag allows you to display table and filled it with data. It only accepts plain HTML.

```xml
<mjml>
  <mj-body>
    <mj-section>
      <mj-column>
        <mj-table>
          <tr style="border-bottom:1px solid #ecedee;text-align:left;padding:15px 0;">
            <th style="padding: 0 15px 0 0;">Year</th>
            <th style="padding: 0 15px;">Language</th>
            <th style="padding: 0 0 0 15px;">Inspired from</th>
          </tr>
          <tr>
            <td style="padding: 0 15px 0 0;">1995</td>
            <td style="padding: 0 15px;">PHP</td>
            <td style="padding: 0 0 0 15px;">C, Shell Unix</td>
          </tr>
          <tr>
            <td style="padding: 0 15px 0 0;">1995</td>
            <td style="padding: 0 15px;">JavaScript</td>
            <td style="padding: 0 0 0 15px;">Scheme, Self</td>
          </tr>
        </mj-table>
      </mj-column>
    </mj-section>
  </mj-body>
</mjml>
```

<p style="text-align: center;" >
  <a href="https://mjml.io/try-it-live/components/table">
    <img width="100px" src="https://mjml.io/assets/img/svg/TRYITLIVE.svg" alt="try it live" />
  </a>
</p>

<aside class="notice">
  `mj-table` is an "ending tag", which means it can contain HTML code which will be left as it is, so it can contain HTML tags with attributes, but it cannot contain other MJML components. In `mj-table` specifically, you can put anything you would put in a `&lt;table&gt;` element. More information about ending tags <a href="#ending-tags">in this section</a>.
</aside>


attribute                   | unit                        | description                    | default value
----------------------------|-----------------------------|------------------------------- |--------------
align                       | left/right/center           | self horizontal alignment      | left
border                      | border                      | table external border          | none
cellpadding                 | pixels                      | space between cells            | n/a
cellspacing                 | pixels                      | space between cell and border  | n/a
color                       | color                       | text header & footer color     | #000000
container-background-color  | color                       | inner element background color | n/a
css-class                   | string                      | class name, added to the root HTML element created | n/a
font-family                 | string                      | font name                      | Ubuntu, Helvetica, Arial, sans-serif
font-size                   | px                          | font size                      | 13px
line-height                 | percent/px                  | space between lines            | 22px
padding                     | percent/px                  | supports up to 4 parameters    | 10px 25px
padding-bottom              | percent/px                  | bottom offset                  | n/a
padding-left                | percent/px                  | left offset                    | n/a
padding-right               | percent/px                  | right offset                   | n/a
padding-top                 | percent/px                  | top offset                     | n/a
role                        | none/presentation           | specify the role attribute     | n/a
table-layout                | auto/fixed/initial/inherit  | sets the table layout.         | auto
width                       | percent/px                  | table width                    | 100%
